#ifndef LIBCSCHEM_UTIL_COMPILE_H
#define LIBCSCHEM_UTIL_COMPILE_H

#include <libcschem/abstract.h>

/* Connect a port to a network. Returns:
   +1: connection is made
    0: already connected (the specific port to the specific net)
   -1: error, no connection made (e.g. netname collision)
*/
int csch_cmp_nameconn_port_net(csch_acomp_t *comp, const char *portname, const char *netname);

/* Merge n1 and n2, keeping one of them, making the other empty; return the
   one kept. (Tries to keep the one with name) */
csch_anet_t *csch_cmp_merge_nets(csch_anet_t *n1, csch_anet_t *n2);


typedef enum {
	/* main op part (not a bitfield) */
	CSCH_CMPDRV_UNIQ = 1,    /* if there are multiple values, they must match */
	CSCH_CMPDRV_CONCAT = 2,  /* concat all values (using comma as separator in case of string) */

	/* modifiers (bitfield) */
	CSCH_CMPDRV_EMPTY_SKIP = 0x100, /* do not write if result is empty */
	CSCH_CMPDRV_EMPTY_DEL  = 0x200, /* del if result is empty */

	/* masks */
	CSCH_CMPDRV_opmask = 0xff   /* the op */
} csch_attr_derive_t;

/* Take all sources of aobj and copy the attribute addressed by skey from each,
   merging them as defined by how. The result is written into aobj as an
   attribute dkey using src. */
int csch_cmp_attr_derive(csch_ahdr_t *aobj, const char *dkey, const char *skey, int prio, csch_source_arg_t src, csch_attr_derive_t how);

#endif
